@@ -4,5 +4,5 @@ use Object::Simple;
 sub m1 : Attr { default => 100};
 sub m4 : Attr { default => 10};
 
-Object::Simple->end;
+Object::Simple->build_class;
 
